scan_snap library
Classes
- Scan
- Provides static methods to interact with the native platform. Used for retrieving platform version and decoding images via native code.
- ScanController
- Controller to interact with the ScanView. Allows controlling the camera and listening for scan events.
- ScanView
Typedefs
- CaptureCallback = void Function(String data)
- Callback type for when a QR code is successfully captured.