Scan class

Provides static methods to interact with the native platform. Used for retrieving platform version and decoding images via native code.

Constructors

Scan()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

platformVersion Future<String>
Returns the platform version from the native side (e.g. "Android 13")
no setter

Static Methods

parse(String path) Future<String?>
Attempts to decode a QR code from the given image path using native code.