ScanController class

Controller to interact with the ScanView. Allows controlling the camera and listening for scan events.

Constructors

ScanController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
Pause camera scanning
resume() → void
Resume camera scanning
setOnCameraReady(VoidCallback callback) → void
Sets a callback that is invoked when the camera is fully initialized.
shutdown() Future<void>
Safely shutdown the camera
toggleTorchMode() → void
Toggle the flashlight on/off
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited